@@ -1,8 +1,8 @@
 __title__ = "pydumpck"
-__description__ = "a pyfile decomplier base on pycdc for windows."
+__description__ = "pydumpck is a tool for decompile exe,elf,pyz,pyc packed by python which is base on pycdc.sometimes its py-file result not exactly right ,maybe could use uncompyle6 etc."
 __keywords__ = ['pydumpck', 'decomplier', 'pe', 'elf', 'pyc', 'pyz']
 __url__ = "https://github.com/serfend/pydumpck"
-__version__ = "1.1.25"
+__version__ = "1.1.26"
 __author__ = "serfend"
 __author_email__ = "serfend@foxmail.com"
 __license__ = "MIT Licence"
